import{c as e,a as s,t,d as a,w as o,x as r,o as l,D as d}from"./index-5CctA6VU.js";const c={class:"w-full flex flex-col items-center pt-10"},i={class:"py-4 text-dimmer font-semibold text-lg"},m={__name:"NotFound",setup:m=>(m,n)=>(l(),e("div",c,[n[1]||(n[1]=s("h1",{class:"text-5xl font-semibold"},"404",-1)),s("p",i,t(m.$t("error.404.message")),1),a(r,{class:"px-4 py-1.5 border rounded-lg",onClick:n[0]||(n[0]=e=>m.$router.replace("/")),theme:"positive"},{default:o(()=>[d(t(m.$t("error.404.return")),1)]),_:1})]))};export{m as default};
